@@ -30,6 +30,7 @@
 #include "cogl-private.h"
 #include "cogl-bitmap-private.h"
 #include "cogl-buffer-private.h"
+#include "cogl-pixel-buffer.h"
 
 #include <string.h>
 
@@ -85,92 +86,28 @@ _cogl_bitmap_convert_premult_status (CoglBitmap      *bmp,
 {
   /* Do we need to unpremultiply? */
   if ((bmp->format & COGL_PREMULT_BIT) > 0 &&
-      (dst_format & COGL_PREMULT_BIT) == 0)
-    /* Try unpremultiplying using imaging library */
-    return (_cogl_bitmap_unpremult (bmp)
-            /* ... or try fallback */
-            || _cogl_bitmap_fallback_unpremult (bmp));
+      (dst_format & COGL_PREMULT_BIT) == 0 &&
+      COGL_PIXEL_FORMAT_CAN_HAVE_PREMULT (dst_format))
+    return _cogl_bitmap_unpremult (bmp);
 
   /* Do we need to premultiply? */
   if ((bmp->format & COGL_PREMULT_BIT) == 0 &&
+      COGL_PIXEL_FORMAT_CAN_HAVE_PREMULT (bmp->format) &&
       (dst_format & COGL_PREMULT_BIT) > 0)
     /* Try premultiplying using imaging library */
-    return (_cogl_bitmap_premult (bmp)
-            /* ... or try fallback */
-            || _cogl_bitmap_fallback_premult (bmp));
+    return _cogl_bitmap_premult (bmp);
 
   return TRUE;
 }
 
-CoglBitmap *
-_cogl_bitmap_convert_format_and_premult (CoglBitmap *bmp,
-                                         CoglPixelFormat   dst_format)
-{
-  CoglPixelFormat src_format = _cogl_bitmap_get_format (bmp);
-  CoglBitmap *dst_bmp;
-
-  /* Is base format different (not considering premult status)? */
-  if ((src_format & ~COGL_PREMULT_BIT) !=
-      (dst_format & ~COGL_PREMULT_BIT))
-    {
-      /* Try converting using imaging library */
-      if ((dst_bmp = _cogl_bitmap_convert (bmp, dst_format)) == NULL)
-        {
-          /* ... or try fallback */
-          if ((dst_bmp = _cogl_bitmap_fallback_convert (bmp,
-                                                        dst_format)) == NULL)
-            return NULL;
-        }
-    }
-  else
-    {
-      int rowstride = _cogl_bitmap_get_rowstride (bmp);
-      int height = _cogl_bitmap_get_height (bmp);
-      guint8 *data;
-
-      /* Copy the bitmap so that we can premultiply in-place */
-
-      if ((data = _cogl_bitmap_map (bmp, COGL_BUFFER_ACCESS_READ, 0)) == NULL)
-        return NULL;
-
-      dst_bmp = _cogl_bitmap_new_from_data (g_memdup (data, height * rowstride),
-                                            src_format,
-                                            _cogl_bitmap_get_width (bmp),
-                                            height,
-                                            rowstride,
-                                            (CoglBitmapDestroyNotify) g_free,
-                                            NULL);
-
-      _cogl_bitmap_unmap (bmp);
-    }
-
-  src_format = _cogl_bitmap_get_format (dst_bmp);
-
-  /* We only need to do a premult conversion if both formats have an
-     alpha channel. If we're converting from RGB to RGBA then the
-     alpha will have been filled with 255 so the premult won't do
-     anything or if we are converting from RGBA to RGB we're losing
-     information so either converting or not will be wrong for
-     transparent pixels */
-  if ((src_format & COGL_A_BIT) == COGL_A_BIT &&
-      (dst_format & COGL_A_BIT) == COGL_A_BIT &&
-      !_cogl_bitmap_convert_premult_status (dst_bmp, dst_format))
-    {
-      cogl_object_unref (dst_bmp);
-      return NULL;
-    }
-
-  return dst_bmp;
-}
-
 CoglBitmap *
 _cogl_bitmap_copy (CoglBitmap *src_bmp)
 {
   CoglBitmap *dst_bmp;
-  CoglPixelFormat src_format = _cogl_bitmap_get_format (src_bmp);
+  CoglPixelFormat src_format = cogl_bitmap_get_format (src_bmp);
   int bpp = _cogl_pixel_format_get_bytes_per_pixel (src_format);
-  int width = _cogl_bitmap_get_width (src_bmp);
-  int height = _cogl_bitmap_get_height (src_bmp);
+  int width = cogl_bitmap_get_width (src_bmp);
+  int height = cogl_bitmap_get_height (src_bmp);
   int dst_rowstride = width * bpp;
 
   /* Round the rowstride up to the next nearest multiple of 4 bytes */
@@ -192,7 +129,7 @@ _cogl_bitmap_copy (CoglBitmap *src_bmp)
   return dst_bmp;
 }
 
-void
+gboolean
 _cogl_bitmap_copy_subregion (CoglBitmap *src,
 			     CoglBitmap *dst,
 			     int         src_x,
@@ -206,9 +143,12 @@ _cogl_bitmap_copy_subregion (CoglBitmap *src,
   guint8 *dstdata;
   int    bpp;
   int    line;
+  gboolean succeeded = FALSE;
 
   /* Intended only for fast copies when format is equal! */
-  g_assert (src->format == dst->format);
+  g_assert ((src->format & ~COGL_PREMULT_BIT) ==
+            (dst->format & ~COGL_PREMULT_BIT));
+
   bpp = _cogl_pixel_format_get_bytes_per_pixel (src->format);
 
   if ((srcdata = _cogl_bitmap_map (src, COGL_BUFFER_ACCESS_READ, 0)))
@@ -225,11 +165,15 @@ _cogl_bitmap_copy_subregion (CoglBitmap *src,
               dstdata += dst->rowstride;
             }
 
+          succeeded = TRUE;
+
           _cogl_bitmap_unmap (dst);
         }
 
       _cogl_bitmap_unmap (src);
     }
+
+  return succeeded;
 }
 
 gboolean
@@ -290,22 +234,9 @@ CoglBitmap *
 cogl_bitmap_new_from_file (const char  *filename,
                            GError     **error)
 {
-  CoglBitmap *bmp;
-
   _COGL_RETURN_VAL_IF_FAIL (error == NULL || *error == NULL, COGL_INVALID_HANDLE);
 
-  if ((bmp = _cogl_bitmap_from_file (filename, error)) == NULL)
-    {
-      /* Try fallback */
-      if ((bmp = _cogl_bitmap_fallback_from_file (filename))
-          && error && *error)
-        {
-          g_error_free (*error);
-          *error = NULL;
-        }
-    }
-
-  return bmp;
+  return _cogl_bitmap_from_file (filename, error);
 }
 
 CoglBitmap *
@@ -334,8 +265,42 @@ cogl_bitmap_new_from_buffer (CoglBuffer *buffer,
   return bmp;
 }
 
+CoglBitmap *
+cogl_bitmap_new_with_size (CoglContext *context,
+                           unsigned int width,
+                           unsigned int height,
+                           CoglPixelFormat format)
+{
+  CoglPixelBuffer *pixel_buffer;
+  CoglBitmap *bitmap;
+  unsigned int rowstride;
+
+  /* creating a buffer to store "any" format does not make sense */
+  if (G_UNLIKELY (format == COGL_PIXEL_FORMAT_ANY))
+    return NULL;
+
+  /* for now we fallback to cogl_pixel_buffer_new, later, we could ask
+   * libdrm a tiled buffer for instance */
+  rowstride = width * _cogl_pixel_format_get_bytes_per_pixel (format);
+
+  pixel_buffer = cogl_pixel_buffer_new (context, height * rowstride, NULL);
+
+  if (G_UNLIKELY (pixel_buffer == NULL))
+    return NULL;
+
+  bitmap = cogl_bitmap_new_from_buffer (COGL_BUFFER (pixel_buffer),
+                                        format,
+                                        width, height,
+                                        rowstride,
+                                        0 /* offset */);
+
+  cogl_object_unref (pixel_buffer);
+
+  return bitmap;
+}
+
 CoglPixelFormat
-_cogl_bitmap_get_format (CoglBitmap *bitmap)
+cogl_bitmap_get_format (CoglBitmap *bitmap)
 {
   return bitmap->format;
 }
@@ -348,29 +313,38 @@ _cogl_bitmap_set_format (CoglBitmap *bitmap,
 }
 
 int
-_cogl_bitmap_get_width (CoglBitmap *bitmap)
+cogl_bitmap_get_width (CoglBitmap *bitmap)
 {
   return bitmap->width;
 }
 
+int
+cogl_bitmap_get_height (CoglBitmap *bitmap)
+{
+  return bitmap->height;
+}
+
+int
+cogl_bitmap_get_rowstride (CoglBitmap *bitmap)
+{
+  return bitmap->rowstride;
+}
+
+CoglPixelBuffer *
+cogl_bitmap_get_buffer (CoglBitmap *bitmap)
+{
+  while (bitmap->shared_bmp)
+    bitmap = bitmap->shared_bmp;
+
+  return COGL_PIXEL_BUFFER (bitmap->buffer);
+}
+
 GQuark
 cogl_bitmap_error_quark (void)
 {
   return g_quark_from_static_string ("cogl-bitmap-error-quark");
 }
 
-int
-_cogl_bitmap_get_height (CoglBitmap *bitmap)
-{
-  return bitmap->height;
-}
-
-int
-_cogl_bitmap_get_rowstride (CoglBitmap *bitmap)
-{
-  return bitmap->rowstride;
-}
-
 guint8 *
 _cogl_bitmap_map (CoglBitmap *bitmap,
                   CoglBufferAccess access,
