@@ -30,7 +30,6 @@
 
 #include <glib.h>
 
-#include "cogl.h"
 #include "cogl-clip-stack.h"
 #include "cogl-clip-state-private.h"
 #include "cogl-context-private.h"
@@ -40,6 +39,12 @@
 #include "cogl-util.h"
 #include "cogl-matrix-private.h"
 
+#ifdef COGL_ENABLE_EXPERIMENTAL_2_0_API
+#include <cogl/cogl2-clip-state.h>
+#else
+#include <cogl/cogl-clip-state.h>
+#endif
+
 void
 cogl_clip_push_window_rectangle (int x_offset,
                                  int y_offset,
