@@ -28,7 +28,6 @@
 #include <stdlib.h>
 #include <glib/gi18n-lib.h>
 
-#include "cogl.h"
 #include "cogl-private.h"
 #include "cogl-debug.h"
 
@@ -55,7 +54,8 @@ static const GDebugKey cogl_log_debug_keys[] = {
   { "offscreen", COGL_DEBUG_OFFSCREEN },
   { "texture-pixmap", COGL_DEBUG_TEXTURE_PIXMAP },
   { "bitmap", COGL_DEBUG_BITMAP },
-  { "clipping", COGL_DEBUG_CLIPPING }
+  { "clipping", COGL_DEBUG_CLIPPING },
+  { "winsys", COGL_DEBUG_WINSYS }
 };
 static const int n_cogl_log_debug_keys =
   G_N_ELEMENTS (cogl_log_debug_keys);
