@@ -31,6 +31,11 @@
 #ifndef __COGL_INDICES_H__
 #define __COGL_INDICES_H__
 
+/* We forward declare the CoglIndices type here to avoid some circular
+ * dependency issues with the following headers.
+ */
+typedef struct _CoglIndices CoglIndices;
+
 #include <cogl/cogl-index-buffer.h>
 
 G_BEGIN_DECLS
@@ -94,10 +99,9 @@ G_BEGIN_DECLS
  * for drawing quads as above.
  */
 
-typedef struct _CoglIndices CoglIndices;
-
 CoglIndices *
-cogl_indices_new (CoglIndicesType type,
+cogl_indices_new (CoglContext *context,
+                  CoglIndicesType type,
                   const void *indices_data,
                   int n_indices);
 
@@ -120,7 +124,7 @@ cogl_indices_set_offset (CoglIndices *indices,
                          gsize offset);
 
 CoglIndices *
-cogl_get_rectangle_indices (int n_rectangles);
+cogl_get_rectangle_indices (CoglContext *context, int n_rectangles);
 
 G_END_DECLS
 
