@@ -24,6 +24,7 @@
 #ifndef __COGL_JOURNAL_PRIVATE_H
 #define __COGL_JOURNAL_PRIVATE_H
 
+#include "cogl-texture.h"
 #include "cogl-handle.h"
 #include "cogl-clip-stack.h"
 
@@ -105,8 +106,7 @@ gboolean
 _cogl_journal_try_read_pixel (CoglJournal *journal,
                               int x,
                               int y,
-                              CoglPixelFormat format,
-                              guint8 *pixel,
+                              CoglBitmap *bitmap,
                               gboolean *found_intersection);
 
 #endif /* __COGL_JOURNAL_PRIVATE_H */
