@@ -41,7 +41,6 @@
 
 #ifdef COGL_PIPELINE_FRAGEND_GLSL
 
-#include "cogl.h"
 #include "cogl-internal.h"
 #include "cogl-context-private.h"
 #include "cogl-handle.h"
@@ -367,11 +366,47 @@ add_constant_lookup (CoglPipelineShaderState *shader_state,
                      CoglPipelineLayer *layer,
                      const char *swizzle)
 {
-  int unit_index = _cogl_pipeline_layer_get_unit_index (layer);
-
   g_string_append_printf (shader_state->header,
                           "_cogl_layer_constant_%i.%s",
-                          unit_index, swizzle);
+                          layer->index, swizzle);
+}
+
+static void
+get_texture_target_string (CoglTextureType texture_type,
+                           const char **target_string_out,
+                           const char **swizzle_out)
+{
+  const char *target_string, *tex_coord_swizzle;
+
+  switch (texture_type)
+    {
+#if 0 /* TODO */
+    case COGL_TEXTURE_TYPE_1D:
+      target_string = "1D";
+      tex_coord_swizzle = "s";
+      break;
+#endif
+
+    case COGL_TEXTURE_TYPE_2D:
+      target_string = "2D";
+      tex_coord_swizzle = "st";
+      break;
+
+    case COGL_TEXTURE_TYPE_3D:
+      target_string = "3D";
+      tex_coord_swizzle = "stp";
+      break;
+
+    case COGL_TEXTURE_TYPE_RECTANGLE:
+      target_string = "2DRect";
+      tex_coord_swizzle = "st";
+      break;
+    }
+
+  if (target_string_out)
+    *target_string_out = target_string;
+  if (swizzle_out)
+    *swizzle_out = tex_coord_swizzle;
 }
 
 static void
@@ -381,22 +416,32 @@ ensure_texture_lookup_generated (CoglPipelineShaderState *shader_state,
 {
   int unit_index = _cogl_pipeline_layer_get_unit_index (layer);
   CoglPipelineSnippetData snippet_data;
+  CoglTextureType texture_type;
+  const char *target_string, *tex_coord_swizzle;
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
   if (shader_state->unit_state[unit_index].sampled)
     return;
 
+  texture_type =
+    _cogl_pipeline_layer_get_texture_type (layer);
+  get_texture_target_string (texture_type,
+                             &target_string,
+                             &tex_coord_swizzle);
+
   shader_state->unit_state[unit_index].sampled = TRUE;
 
   g_string_append_printf (shader_state->header,
                           "vec4 cogl_texel%i;\n",
-                          unit_index);
+                          layer->index);
 
   g_string_append_printf (shader_state->source,
-                          "  cogl_texel%i = cogl_texture_lookup%i (",
-                          unit_index,
-                          unit_index);
+                          "  cogl_texel%i = cogl_texture_lookup%i ("
+                          "cogl_sampler%i, ",
+                          layer->index,
+                          layer->index,
+                          layer->index);
 
   /* If point sprite coord generation is being used then divert to the
      built-in varying var for that instead of the texture
@@ -422,71 +467,22 @@ ensure_texture_lookup_generated (CoglPipelineShaderState *shader_state,
      to be replaced */
   if (!has_replace_hook (layer, COGL_SNIPPET_HOOK_TEXTURE_LOOKUP))
     {
-      CoglHandle texture = _cogl_pipeline_layer_get_texture (layer);
-      const char *target_string, *tex_coord_swizzle;
-
-      if (texture == NULL)
-        {
-          target_string = "2D";
-          tex_coord_swizzle = "st";
-        }
-      else
-        {
-          GLenum gl_target;
-
-          cogl_texture_get_gl_texture (texture, NULL, &gl_target);
-          switch (gl_target)
-            {
-#ifdef HAVE_COGL_GL
-            case GL_TEXTURE_1D:
-              target_string = "1D";
-              tex_coord_swizzle = "s";
-              break;
-#endif
-
-            case GL_TEXTURE_2D:
-              target_string = "2D";
-              tex_coord_swizzle = "st";
-              break;
-
-#ifdef GL_ARB_texture_rectangle
-            case GL_TEXTURE_RECTANGLE_ARB:
-              target_string = "2DRect";
-              tex_coord_swizzle = "st";
-              break;
-#endif
-
-            case GL_TEXTURE_3D:
-              target_string = "3D";
-              tex_coord_swizzle = "stp";
-              break;
-
-            default:
-              g_assert_not_reached ();
-            }
-        }
-
-      /* Create a sampler uniform */
-      if (G_LIKELY (!COGL_DEBUG_ENABLED (COGL_DEBUG_DISABLE_TEXTURING)))
-        g_string_append_printf (shader_state->header,
-                                "uniform sampler%s _cogl_sampler_%i;\n",
-                                target_string,
-                                unit_index);
-
       g_string_append_printf (shader_state->header,
                               "vec4\n"
-                              "cogl_real_texture_lookup%i (vec4 coords)\n"
+                              "cogl_real_texture_lookup%i (sampler%s tex,\n"
+                              "                            vec4 coords)\n"
                               "{\n"
                               "  return ",
-                              unit_index);
+                              layer->index,
+                              target_string);
 
       if (G_UNLIKELY (COGL_DEBUG_ENABLED (COGL_DEBUG_DISABLE_TEXTURING)))
         g_string_append (shader_state->header,
                          "vec4 (1.0, 1.0, 1.0, 1.0);\n");
       else
         g_string_append_printf (shader_state->header,
-                                "texture%s (_cogl_sampler_%i, coords.%s);\n",
-                                target_string, unit_index, tex_coord_swizzle);
+                                "texture%s (tex, coords.%s);\n",
+                                target_string, tex_coord_swizzle);
 
       g_string_append (shader_state->header, "}\n");
     }
@@ -496,15 +492,17 @@ ensure_texture_lookup_generated (CoglPipelineShaderState *shader_state,
   snippet_data.snippets = get_layer_fragment_snippets (layer);
   snippet_data.hook = COGL_SNIPPET_HOOK_TEXTURE_LOOKUP;
   snippet_data.chain_function = g_strdup_printf ("cogl_real_texture_lookup%i",
-                                                 unit_index);
+                                                 layer->index);
   snippet_data.final_name = g_strdup_printf ("cogl_texture_lookup%i",
-                                             unit_index);
+                                             layer->index);
   snippet_data.function_prefix = g_strdup_printf ("cogl_texture_lookup_hook%i",
-                                                  unit_index);
+                                                  layer->index);
   snippet_data.return_type = "vec4";
   snippet_data.return_variable = "cogl_texel";
-  snippet_data.arguments = "cogl_tex_coord";
-  snippet_data.argument_declarations = "vec4 cogl_tex_coord";
+  snippet_data.arguments = "cogl_sampler, cogl_tex_coord";
+  snippet_data.argument_declarations =
+    g_strdup_printf ("sampler%s cogl_sampler, vec4 cogl_tex_coord",
+                     target_string);
   snippet_data.source_buf = shader_state->header;
 
   _cogl_pipeline_snippet_generate_code (&snippet_data);
@@ -512,6 +510,7 @@ ensure_texture_lookup_generated (CoglPipelineShaderState *shader_state,
   g_free ((char *) snippet_data.chain_function);
   g_free ((char *) snippet_data.final_name);
   g_free ((char *) snippet_data.function_prefix);
+  g_free ((char *) snippet_data.argument_declarations);
 }
 
 static void
@@ -548,7 +547,7 @@ add_arg (CoglPipelineShaderState *shader_state,
     case COGL_PIPELINE_COMBINE_SOURCE_TEXTURE:
       g_string_append_printf (shader_source,
                               "cogl_texel%i.%s",
-                              _cogl_pipeline_layer_get_unit_index (layer),
+                              layer->index,
                               swizzle);
       break;
 
@@ -574,43 +573,37 @@ add_arg (CoglPipelineShaderState *shader_state,
       break;
 
     default:
-      if (src >= COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0 &&
-          src < COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0 + 32)
-        g_string_append_printf (shader_source,
-                                "cogl_texel%i.%s",
-                                src - COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0,
-                                swizzle);
+      {
+        int layer_num = src - COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0;
+        CoglPipelineGetLayerFlags flags = COGL_PIPELINE_GET_LAYER_NO_CREATE;
+        CoglPipelineLayer *other_layer =
+          _cogl_pipeline_get_layer_with_flags (pipeline, layer_num, flags);
+
+        if (other_layer == NULL)
+          {
+            static gboolean warning_seen = FALSE;
+            if (!warning_seen)
+              {
+                g_warning ("The application is trying to use a texture "
+                           "combine with a layer number that does not exist");
+                warning_seen = TRUE;
+              }
+            g_string_append_printf (shader_source,
+                                    "vec4 (1.0, 1.0, 1.0, 1.0).%s",
+                                    swizzle);
+          }
+        else
+          g_string_append_printf (shader_source,
+                                  "cogl_texel%i.%s",
+                                  other_layer->index,
+                                  swizzle);
+      }
       break;
     }
 
   g_string_append_c (shader_source, ')');
 }
 
-
-typedef struct
-{
-  int unit_index;
-  CoglPipelineLayer *layer;
-} FindPipelineLayerData;
-
-static gboolean
-find_pipeline_layer_cb (CoglPipelineLayer *layer,
-                        void *user_data)
-{
-  FindPipelineLayerData *data = user_data;
-  int unit_index;
-
-  unit_index = _cogl_pipeline_layer_get_unit_index (layer);
-
-  if (unit_index == data->unit_index)
-    {
-      data->layer = layer;
-      return FALSE;
-    }
-
-  return TRUE;
-}
-
 static void
 ensure_arg_generated (CoglPipeline *pipeline,
                       CoglPipelineLayer *layer,
@@ -633,7 +626,7 @@ ensure_arg_generated (CoglPipeline *pipeline,
           {
             g_string_append_printf (shader_state->header,
                                     "uniform vec4 _cogl_layer_constant_%i;\n",
-                                    unit_index);
+                                    layer->index);
             shader_state->unit_state[unit_index].combine_constant_used = TRUE;
           }
       }
@@ -651,21 +644,17 @@ ensure_arg_generated (CoglPipeline *pipeline,
       break;
 
     default:
-      if (src >= COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0 &&
-          src < COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0 + 32)
+      if (src >= COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0)
         {
-          FindPipelineLayerData data;
+          int layer_num = src - COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0;
+          CoglPipelineGetLayerFlags flags = COGL_PIPELINE_GET_LAYER_NO_CREATE;
+          CoglPipelineLayer *other_layer =
+            _cogl_pipeline_get_layer_with_flags (pipeline, layer_num, flags);
 
-          data.unit_index = src - COGL_PIPELINE_COMBINE_SOURCE_TEXTURE0;
-          data.layer = layer;
-
-          _cogl_pipeline_foreach_layer_internal (pipeline,
-                                                 find_pipeline_layer_cb,
-                                                 &data);
-
-          ensure_texture_lookup_generated (shader_state,
-                                           pipeline,
-                                           data.layer);
+          if (other_layer)
+            ensure_texture_lookup_generated (shader_state,
+                                             pipeline,
+                                             other_layer);
         }
       break;
     }
@@ -1041,6 +1030,24 @@ _cogl_pipeline_fragend_glsl_end (CoglPipeline *pipeline,
           CoglPipelineLayer *last_layer;
           LayerData *layer_data, *tmp;
 
+          /* We always emit sampler uniforms in case there will be custom
+           * layer snippets that want to sample arbitrary layers. */
+
+          COGL_LIST_FOREACH (layer_data, &shader_state->layers, list_node)
+            {
+              CoglPipelineLayer *layer = layer_data->layer;
+              CoglTextureType texture_type =
+                _cogl_pipeline_layer_get_texture_type (layer);
+              const char *target_string;
+
+              get_texture_target_string (texture_type, &target_string, NULL);
+
+              g_string_append_printf (shader_state->header,
+                                      "uniform sampler%s cogl_sampler%i;\n",
+                                      target_string,
+                                      layer->index);
+            }
+
           last_layer = COGL_LIST_FIRST (&shader_state->layers)->layer;
 
           ensure_layer_generated (pipeline, last_layer->index);
