@@ -34,7 +34,10 @@
  * 3D Maths Primer for Graphics and Game Development ISBN-10: 1556229119
  */
 
-#include <cogl.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <cogl-util.h>
 #include <cogl-quaternion.h>
 #include <cogl-quaternion-private.h>
