@@ -160,8 +160,7 @@ _cogl_texture_determine_internal_format (CoglPixelFormat src_format,
    * this. */
   if (dst_format == COGL_PIXEL_FORMAT_ANY)
     {
-      if ((src_format & COGL_A_BIT) &&
-          src_format != COGL_PIXEL_FORMAT_A_8)
+      if (COGL_PIXEL_FORMAT_CAN_HAVE_PREMULT (src_format))
         return src_format | COGL_PREMULT_BIT;
       else
         return src_format;
@@ -178,7 +177,7 @@ _cogl_texture_prepare_for_upload (CoglBitmap      *src_bmp,
                                   GLenum          *out_glformat,
                                   GLenum          *out_gltype)
 {
-  CoglPixelFormat src_format = _cogl_bitmap_get_format (src_bmp);
+  CoglPixelFormat src_format = cogl_bitmap_get_format (src_bmp);
   CoglBitmap *dst_bmp;
 
   _COGL_GET_CONTEXT (ctx, NULL);
@@ -201,15 +200,11 @@ _cogl_texture_prepare_for_upload (CoglBitmap      *src_bmp,
       if (_cogl_texture_needs_premult_conversion (src_format,
                                                   dst_format))
         {
-          dst_bmp = _cogl_bitmap_copy (src_bmp);
+          dst_bmp = _cogl_bitmap_convert (src_bmp,
+                                          src_format ^ COGL_PREMULT_BIT);
 
-          if (!_cogl_bitmap_convert_premult_status (dst_bmp,
-                                                    src_format ^
-                                                    COGL_PREMULT_BIT))
-            {
-              cogl_object_unref (dst_bmp);
-              return NULL;
-            }
+          if (dst_bmp == NULL)
+            return NULL;
         }
       else
         dst_bmp = cogl_object_ref (src_bmp);
@@ -237,8 +232,7 @@ _cogl_texture_prepare_for_upload (CoglBitmap      *src_bmp,
                                                                 out_gltype);
 
       if (closest_format != src_format)
-        dst_bmp = _cogl_bitmap_convert_format_and_premult (src_bmp,
-                                                           closest_format);
+        dst_bmp = _cogl_bitmap_convert (src_bmp, closest_format);
       else
         dst_bmp = cogl_object_ref (src_bmp);
     }
@@ -403,7 +397,7 @@ cogl_texture_new_from_file (const char        *filename,
   if (bmp == NULL)
     return NULL;
 
-  src_format = _cogl_bitmap_get_format (bmp);
+  src_format = cogl_bitmap_get_format (bmp);
 
   /* We know that the bitmap data is solely owned by this function so
      we can do the premult conversion in place. This avoids having to
@@ -503,62 +497,6 @@ cogl_texture_new_from_sub_texture (CoglTexture *full_texture,
                                              sub_width, sub_height));
 }
 
-CoglTexture *
-cogl_texture_new_from_buffer_EXP (CoglPixelBuffer    *buffer,
-                                  unsigned int        width,
-                                  unsigned int        height,
-                                  CoglTextureFlags    flags,
-                                  CoglPixelFormat     format,
-                                  CoglPixelFormat     internal_format,
-                                  unsigned int        rowstride,
-                                  const unsigned int  offset)
-{
-  CoglTexture *texture;
-  CoglBuffer *cogl_buffer;
-  CoglPixelBuffer *pixel_buffer;
-  CoglBitmap *bmp;
-
-  _COGL_RETURN_VAL_IF_FAIL (cogl_is_buffer (buffer), NULL);
-
-  if (format == COGL_PIXEL_FORMAT_ANY)
-    return NULL;
-
-  cogl_buffer = COGL_BUFFER (buffer);
-  pixel_buffer = COGL_PIXEL_BUFFER (buffer);
-
-  /* Rowstride from CoglBuffer or even width * bpp if not given */
-  if (rowstride == 0)
-    rowstride = pixel_buffer->stride;
-  if (rowstride == 0)
-    rowstride = width * _cogl_pixel_format_get_bytes_per_pixel (format);
-
-  /* use the CoglBuffer height and width as last resort */
-  if (width == 0)
-    width = pixel_buffer->width;
-  if (height == 0)
-    height = pixel_buffer->height;
-  if (width == 0 || height == 0)
-    {
-      /* no width or height specified, neither at creation time (because the
-       * array was created by cogl_pixel_buffer_new()) nor when calling this
-       * function */
-      return NULL;
-    }
-
-  /* Wrap the buffer into a bitmap */
-  bmp = cogl_bitmap_new_from_buffer (cogl_buffer,
-                                     format,
-                                     width, height,
-                                     rowstride,
-                                     offset);
-
-  texture = cogl_texture_new_from_bitmap (bmp, flags, internal_format);
-
-  cogl_object_unref (bmp);
-
-  return texture;
-}
-
 unsigned int
 cogl_texture_get_width (CoglTexture *texture)
 {
@@ -683,9 +621,9 @@ cogl_texture_set_region_from_bitmap (CoglTexture *texture,
 {
   gboolean ret;
 
-  _COGL_RETURN_VAL_IF_FAIL ((_cogl_bitmap_get_width (bmp) - src_x)
+  _COGL_RETURN_VAL_IF_FAIL ((cogl_bitmap_get_width (bmp) - src_x)
                             >= dst_width, FALSE);
-  _COGL_RETURN_VAL_IF_FAIL ((_cogl_bitmap_get_height (bmp) - src_y)
+  _COGL_RETURN_VAL_IF_FAIL ((cogl_bitmap_get_height (bmp) - src_y)
                             >= dst_height, FALSE);
 
   /* Shortcut out early if the image is empty */
@@ -881,9 +819,9 @@ _cogl_texture_draw_and_read (CoglTexture *texture,
   CoglFramebuffer *framebuffer;
   float viewport[4];
   CoglBitmap *alpha_bmp;
-  int target_width = _cogl_bitmap_get_width (target_bmp);
-  int target_height = _cogl_bitmap_get_height (target_bmp);
-  int target_rowstride = _cogl_bitmap_get_rowstride (target_bmp);
+  int target_width = cogl_bitmap_get_width (target_bmp);
+  int target_height = cogl_bitmap_get_height (target_bmp);
+  int target_rowstride = cogl_bitmap_get_rowstride (target_bmp);
 
   _COGL_GET_CONTEXT (ctx, FALSE);
 
@@ -1021,6 +959,7 @@ get_texture_bits_via_offscreen (CoglTexture    *texture,
 {
   CoglOffscreen *offscreen;
   CoglFramebuffer *framebuffer;
+  CoglBitmap *bitmap;
 
   _COGL_GET_CONTEXT (ctx, FALSE);
 
@@ -1037,19 +976,17 @@ get_texture_bits_via_offscreen (CoglTexture    *texture,
 
   framebuffer = COGL_FRAMEBUFFER (offscreen);
 
-  if (!cogl_framebuffer_allocate (framebuffer, NULL))
-    {
-      cogl_object_unref (framebuffer);
-      return FALSE;
-    }
-
-  cogl_push_framebuffer (framebuffer);
-
-  _cogl_read_pixels_with_rowstride (x, y, width, height,
-                                    COGL_READ_PIXELS_COLOR_BUFFER,
-                                    dst_format, dst_bits, dst_rowstride);
-
-  cogl_pop_framebuffer ();
+  bitmap = _cogl_bitmap_new_from_data (dst_bits,
+                                       dst_format,
+                                       width, height,
+                                       dst_rowstride,
+                                       NULL, /* destroy_fn */
+                                       NULL /* destroy_fn_data */);
+  cogl_framebuffer_read_pixels_into_bitmap (framebuffer,
+                                            x, y,
+                                            COGL_READ_PIXELS_COLOR_BUFFER,
+                                            bitmap);
+  cogl_object_unref (bitmap);
 
   cogl_object_unref (framebuffer);
 
@@ -1120,9 +1057,9 @@ texture_get_cb (CoglTexture *texture,
                 void        *user_data)
 {
   CoglTextureGetData *tg_data = user_data;
-  CoglPixelFormat format = _cogl_bitmap_get_format (tg_data->target_bmp);
+  CoglPixelFormat format = cogl_bitmap_get_format (tg_data->target_bmp);
   int bpp = _cogl_pixel_format_get_bytes_per_pixel (format);
-  unsigned int rowstride = _cogl_bitmap_get_rowstride (tg_data->target_bmp);
+  unsigned int rowstride = cogl_bitmap_get_rowstride (tg_data->target_bmp);
   int subtexture_width = cogl_texture_get_width (texture);
   int subtexture_height = cogl_texture_get_height (texture);
 
@@ -1198,14 +1135,17 @@ cogl_texture_get_data (CoglTexture     *texture,
   int              y;
   int              tex_width;
   int              tex_height;
+  CoglPixelFormat  texture_format;
 
   CoglTextureGetData tg_data;
 
   _COGL_GET_CONTEXT (ctx, 0);
 
+  texture_format = cogl_texture_get_format (texture);
+
   /* Default to internal format if none specified */
   if (format == COGL_PIXEL_FORMAT_ANY)
-    format = cogl_texture_get_format (texture);
+    format = texture_format;
 
   tex_width = cogl_texture_get_width (texture);
   tex_height = cogl_texture_get_height (texture);
@@ -1226,6 +1166,12 @@ cogl_texture_get_data (CoglTexture     *texture,
                                                        &closest_gl_type);
   closest_bpp = _cogl_pixel_format_get_bytes_per_pixel (closest_format);
 
+  /* We can assume that whatever data GL gives us will have the
+     premult status of the original texture */
+  if (COGL_PIXEL_FORMAT_CAN_HAVE_PREMULT (closest_format))
+    closest_format = ((closest_format & ~COGL_PREMULT_BIT) |
+                      (texture_format & COGL_PREMULT_BIT));
+
   /* Is the requested format supported? */
   if (closest_format == format)
     /* Target user data directly */
@@ -1294,8 +1240,7 @@ cogl_texture_get_data (CoglTexture     *texture,
       int new_bmp_rowstride;
 
       /* Convert to requested format */
-      new_bmp = _cogl_bitmap_convert_format_and_premult (target_bmp,
-                                                         format);
+      new_bmp = _cogl_bitmap_convert (target_bmp, format);
 
       /* Free intermediate data and return if failed */
       cogl_object_unref (target_bmp);
@@ -1303,7 +1248,7 @@ cogl_texture_get_data (CoglTexture     *texture,
       if (new_bmp == NULL)
         return 0;
 
-      new_bmp_rowstride = _cogl_bitmap_get_rowstride (new_bmp);
+      new_bmp_rowstride = cogl_bitmap_get_rowstride (new_bmp);
       new_bmp_data = _cogl_bitmap_map (new_bmp, COGL_BUFFER_ACCESS_WRITE,
                                        COGL_BUFFER_MAP_HINT_DISCARD);
 
