@@ -6,8 +6,6 @@
 
 #include <wayland-server.h>
 
-CoglColor black;
-
 typedef struct _CoglandCompositor CoglandCompositor;
 
 typedef struct
@@ -82,6 +80,7 @@ struct _CoglandCompositor
   GQueue frame_callbacks;
 
   CoglPrimitive *triangle;
+  CoglPipeline *triangle_pipeline;
 
   GSource *wayland_event_source;
 
@@ -512,13 +511,10 @@ paint_cb (void *user_data)
 
       cogl_push_framebuffer (fb);
 
-#if 0
-      cogl_framebuffer_clear (fb, COGL_BUFFER_BIT_COLOR);
-#else
-      cogl_clear (&black, COGL_BUFFER_BIT_COLOR);
-#endif
+      cogl_framebuffer_clear4f (fb, COGL_BUFFER_BIT_COLOR, 0, 0, 0, 1);
 
-      cogl_primitive_draw (compositor->triangle);
+      cogl_framebuffer_draw_primitive (fb, compositor->triangle_pipeline,
+                                       compositor->triangle);
 
       for (l2 = compositor->surfaces; l2; l2 = l2->next)
         {
@@ -531,7 +527,7 @@ paint_cb (void *user_data)
               cogl_rectangle (-1, 1, 1, -1);
             }
         }
-      cogl_framebuffer_swap_buffers (fb);
+      cogl_onscreen_swap_buffers (COGL_ONSCREEN (fb));
 
       cogl_pop_framebuffer ();
     }
@@ -755,8 +751,10 @@ main (int argc, char **argv)
   if (wl_display_add_socket (compositor.wayland_display, "wayland-0"))
     g_error ("Failed to create socket");
 
-  compositor.triangle = cogl_primitive_new_p2c4 (COGL_VERTICES_MODE_TRIANGLES,
+  compositor.triangle = cogl_primitive_new_p2c4 (compositor.cogl_context,
+                                                 COGL_VERTICES_MODE_TRIANGLES,
                                                  3, triangle_vertices);
+  compositor.triangle_pipeline = cogl_pipeline_new (compositor.cogl_context);
 
   g_timeout_add (16, paint_cb, &compositor);
 
