@@ -103,7 +103,7 @@ test_cogl_color_mask (TestUtilsGTestFixture *fixture,
 
   paint (&state);
 
-  if (g_test_verbose ())
+  if (cogl_test_verbose ())
     g_print ("OK\n");
 }
 
